@@ -34,5 +34,3 @@ const char mimeHidden[] = COPYQ_MIME_PREFIX "hidden";
 const char mimeShortcut[] = COPYQ_MIME_PREFIX "shortcut";
 const char mimeColor[] = COPYQ_MIME_PREFIX "color";
 const char mimeOutputTab[] = COPYQ_MIME_PREFIX "output-tab";
-const char mimeSyncToClipboard[] = COPYQ_MIME_PREFIX "sync-to-clipboard";
-const char mimeSyncToSelection[] = COPYQ_MIME_PREFIX "sync-to-selection";
