@@ -47,10 +47,9 @@ signals:
     void changed();
     void commandTextChanged(const QString &command);
 
-private slots:
-    void on_plainTextEditCommand_textChanged();
-
 private:
+    void onPlainTextEditCommandTextChanged();
+
     Ui::CommandEdit *ui;
 };
 
