@@ -74,6 +74,52 @@ void addColor(
         *a = normalizeColorValue(*a + x * toAdd.alpha());
 }
 
+int fitFontWeight(int weight, int low, int high, int highCss)
+{
+    const int diffCss = 100;
+    const int lowCss = highCss - diffCss;
+    if (weight == low)
+        return lowCss;
+
+    const int diff = high - low;
+    return lowCss + diffCss * weight / diff;
+}
+
+int getFontWeightForStyleSheet(int weight)
+{
+    // Copied from QFont sources (not available in all Qt versions).
+    enum Weight {
+        Thin     = 0,    // 100
+        ExtraLight = 12, // 200
+        Light    = 25,   // 300
+        Normal   = 50,   // 400
+        Medium   = 57,   // 500
+        DemiBold = 63,   // 600
+        Bold     = 75,   // 700
+        ExtraBold = 81,  // 800
+        Black    = 87    // 900
+    };
+
+    if (weight < ExtraLight)
+        return fitFontWeight(weight, Thin, ExtraLight, 200);
+    if (weight < Light)
+        return fitFontWeight(weight, ExtraLight, Light, 300);
+    if (weight < Normal)
+        return fitFontWeight(weight, Light, Normal, 400);
+    if (weight < Medium)
+        return fitFontWeight(weight, Normal, Medium, 500);
+    if (weight < DemiBold)
+        return fitFontWeight(weight, Medium, DemiBold, 600);
+    if (weight < Bold)
+        return fitFontWeight(weight, DemiBold, Bold, 700);
+    if (weight < ExtraBold)
+        return fitFontWeight(weight, Bold, ExtraBold, 800);
+    if (weight < Black)
+        return fitFontWeight(weight, ExtraBold, Black, 900);
+
+    return 900;
+}
+
 QString getFontStyleSheet(const QString &fontString, double scale = 1.0)
 {
     QFont font;
@@ -101,10 +147,8 @@ QString getFontStyleSheet(const QString &fontString, double scale = 1.0)
                         font.underline() ? "underline" : "",
                         font.overline() ? "overline" : "")
                    );
-    // QFont::weight -> CSS
-    // (normal) 50 -> 400
-    // (bold)   75 -> 700
-    int w = font.weight() * 12 - 200;
+
+    const int w = getFontWeightForStyleSheet( font.weight() );
     result.append( QString(";font-weight:%1").arg(w) );
 
     result.append(";");
